import {
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "./chunk.SEHSDSX2.js";

// libs/core/src/controllers/dynamic-styles-controller.ts
var _useLegacyStylesheets, _initialStyleSheets, _styleSheets, _legacyStyleSheets, _applyStylesLegacy, applyStylesLegacy_fn, _applyStyles, applyStyles_fn;
var DynamicStylesController = class {
  constructor(host) {
    __privateAdd(this, _applyStylesLegacy);
    __privateAdd(this, _applyStyles);
    __privateAdd(this, _useLegacyStylesheets, !supportsConstructedStylesheets());
    __privateAdd(this, _initialStyleSheets, []);
    __privateAdd(this, _styleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _legacyStyleSheets, /* @__PURE__ */ new Map());
    this.host = host;
    this.host.addController(this);
  }
  hostConnected() {
    if (this.host.shadowRoot && __privateGet(this, _initialStyleSheets).length === 0) {
      __privateSet(this, _initialStyleSheets, [
        ...this.host.shadowRoot.adoptedStyleSheets || []
      ]);
    }
  }
  /**
   * Injects CSS into the host element's shadow root. The key is used to
   * identify the styles and can be used to update the styles later. If
   * you need to clear style for a particular key, you can call `inject`
   * with an empty string as the `styles` parameter.
   *
   * @param key - A unique key to identify the styles.
   * @param styles - The CSSResult to inject.
   */
  inject(key, styles) {
    if (__privateGet(this, _useLegacyStylesheets)) {
      const cssText = Array.isArray(styles) ? styles.map((style) => style.toString()).join("") : styles.toString();
      __privateMethod(this, _applyStylesLegacy, applyStylesLegacy_fn).call(this, key, cssText);
    } else {
      styles.styleSheet && __privateMethod(this, _applyStyles, applyStyles_fn).call(this, key, styles.styleSheet);
    }
  }
  /**
   * Clears all styles of the component, including any initial styles.
   */
  clearAll() {
    var _a;
    if (__privateGet(this, _useLegacyStylesheets)) {
      __privateGet(this, _legacyStyleSheets).forEach((styleEl) => styleEl.remove());
      (_a = this.host.shadowRoot) == null ? void 0 : _a.querySelectorAll("style").forEach((style) => style.innerHTML = "");
      __privateGet(this, _legacyStyleSheets).clear();
    } else {
      if (this.host.shadowRoot) {
        this.host.shadowRoot.adoptedStyleSheets = [];
        __privateGet(this, _styleSheets).clear();
        __privateSet(this, _initialStyleSheets, []);
      }
    }
  }
};
_useLegacyStylesheets = new WeakMap();
_initialStyleSheets = new WeakMap();
_styleSheets = new WeakMap();
_legacyStyleSheets = new WeakMap();
_applyStylesLegacy = new WeakSet();
applyStylesLegacy_fn = function(key, cssText) {
  var _a;
  let styleEl = __privateGet(this, _legacyStyleSheets).get(key);
  if (!styleEl) {
    styleEl = document.createElement("style");
    __privateGet(this, _legacyStyleSheets).set(key, styleEl);
  }
  styleEl.textContent = cssText;
  (_a = this.host.shadowRoot) == null ? void 0 : _a.appendChild(styleEl);
};
_applyStyles = new WeakSet();
applyStyles_fn = function(key, styleSheet) {
  if (!this.host.shadowRoot)
    return;
  __privateGet(this, _styleSheets).set(key, styleSheet);
  this.host.shadowRoot.adoptedStyleSheets = [
    ...__privateGet(this, _initialStyleSheets),
    ...Array.from(__privateGet(this, _styleSheets).values())
  ];
};
function supportsConstructedStylesheets() {
  try {
    new CSSStyleSheet();
    return true;
  } catch (e) {
    return false;
  }
}

export {
  DynamicStylesController,
  supportsConstructedStylesheets
};
