// libs/core/src/mixins/focusable.ts
var Focusable = (superClass) => {
  class HighlightableElement extends superClass {
    constructor() {
      super(...arguments);
      this.onblur = (e) => {
        this.setAttribute("tabindex", "-1");
        this.dispatchEvent(
          new FocusEvent("gds-blur", {
            bubbles: true,
            composed: true,
            relatedTarget: e.relatedTarget
          })
        );
      };
      this.onfocus = (e) => {
        this.dispatchEvent(
          new FocusEvent("gds-focus", {
            bubbles: true,
            composed: true,
            relatedTarget: e.relatedTarget
          })
        );
      };
    }
    focus(options) {
      this.setAttribute("tabindex", "0");
      super.focus(options);
    }
  }
  return HighlightableElement;
};

// libs/core/src/primitives/listbox/option.styles.ts
import { css } from "lit";
var style = css`
  @layer base, reset;

  @layer base {
    :host(:not(:last-child)) {
      border-bottom: 1px solid var(--gds-sys-color-border-stroke-variant2);
    }

    :host div {
      display: flex;
      align-items: center;
      user-select: none;
      padding-inline: var(--gds-space-m);
      padding-block: var(--gds-space-m);
      cursor: pointer;
      font-size: var(--gds-text-size-label-input-large);
      font-weight: var(--gds-text-weight-regular);
      line-height: var(--gds-text-line-height-label-input-large);
      gap: 1ch;
      max-width: 100%;
      box-sizing: border-box;
    }

    :host([highlighted]) div {
      background-color: var(--gds-sys-color-container-container-shade1);
      color: var(--gds-sys-color-content-content-inverse);
    }

    :host(:hover:not([highlighted])) div {
      background-color: var(--gds-sys-color-container-container-dim1);
    }

    :host(:focus-visible) {
      outline: auto;
      outline-offset: -6px;
      outline-color: currentColor;
      outline-width: 2px;
    }

    :host([aria-hidden='true']) div {
      display: none;
    }

    .checkbox {
      display: flex;
      align-items: center;
      justify-content: center;
      height: 1lh;
      width: auto;
      box-sizing: border-box;
      position: relative;
      aspect-ratio: 1/1;
      border-radius: var(--gds-space-2xs);
      border: var(--gds-space-3xs) solid currentColor;
      padding: var(--gds-space-3xs);

      &.checked {
        background-color: currentColor;

        gds-icon-checkmark {
          &::part(icon) {
            color: var(--gds-sys-color-base-white);
            stroke-width: var(--gds-space-2xs);
          }
        }
      }
    }
  }
`;
var option_styles_default = style;

export {
  Focusable,
  option_styles_default
};
