import { Directive, ElementPart, PartInfo } from 'lit/directive.js';
/**
 * A directive that forwards attributes from the host element to the target element in the component.
 *
 * If an attribute name starts with `gds-`, the `gds-` prefix is removed.
 *
 * @param filter A function that determines which attributes to forward.
 *
 * @example
 * Here, all attributes that start with `gds-aria` or are named `gds-role`, will be forwarded:
 * ```html
 * <button
 *    ${forwardAttributes(
 *      (attr) => attr.name.startsWith('gds-aria') || attr.name === 'gds-role'
 *    )}
 * >Button</button>
 * ```
 */
declare class ForwardAttributesDirective extends Directive {
    constructor(partInfo: PartInfo);
    render(_filter: (attr: Attr) => boolean): symbol;
    update(part: ElementPart, [filter]: Parameters<this['render']>): void;
}
export declare const forwardAttributes: (_filter: (attr: Attr) => boolean) => import("lit-html/directive").DirectiveResult<typeof ForwardAttributesDirective>;
export {};
